@@ -109,12 +109,12 @@ class Query(object):
         offset = offset or self.offset
         query_id = self.id
         workspace_id = self.workspace_id
-        try:
-            urls = self.request.get(f'api/v1/query/{query_id}/result/signedUrls?workspaceId={workspace_id}').get('signedUrls')
+        urls = self.request.get(f'api/v1/query/{query_id}/result/signedUrls?workspaceId={workspace_id}').get('signedUrls')
+        if len(urls) is 0:
+            df = pd.DataFrame({})
+        else:
             dfs = [self.__get_pd_by_parquet_file(url) for url in urls]
             df = pd.concat(dfs)
-        except:
-            df = pd.DataFrame({})
         self._columns = list(map(lambda column: {'name': column}, list(df.columns)))
         self.row_count = df.shape[0]
         self.data = df.iloc[offset:limit + offset, :].to_numpy().tolist()
