@@ -31,14 +31,15 @@ class Workspace(object):
             workspace_id=workspace_id,
             replaceLocalhostString=replaceLocalhostString
         )
-    def gen_query(self, sql, cache_refresh, cache_ttl, data_format):
+    def gen_query(self, sql, cache_refresh, cache_ttl, data_format, fetch_by):
         return Query(
             request=self.request,
             workspace_id=self.workspace_id,
             sql=sql,
             cache_refresh=cache_refresh,
             cache_ttl=cache_ttl,
-            data_format=data_format
+            data_format=data_format,
+            fetch_by=fetch_by
         )
 
     def _replace_localhost(self, url):
